@@ -20,7 +20,17 @@ test_that("FsDiscretizeTransformer returns the same result", {
 
 test_that("Print FsDiscretizeTransformer", {
   disc <- discretize(Species ~ ., iris)
-  invisible(capture.output(print(extract_discretize_transformer(disc))))
+  desc <- capture.output(print(extract_discretize_transformer(disc)))
+
+  expected <- c("FsDiscretizeTransformer", "", "Cutpoints:", "  Sepal.Length: -Inf, 5.55, 6.15, Inf",
+                "  Sepal.Width: -Inf, 2.95, 3.35, Inf", "  Petal.Length: -Inf, 2.45, 4.75, Inf",
+                "  Petal.Width: -Inf, 0.8, 1.75, Inf", "", "FsDiscretizeTransformer allows to discretize data using",
+                "discretize_transform(disc, newData) function.FsDiscretizeTransformer",
+                "", "Cutpoints:", "  Sepal.Length: -Inf, 5.55, 6.15, Inf", "  Sepal.Width: -Inf, 2.95, 3.35, Inf",
+                "  Petal.Length: -Inf, 2.45, 4.75, Inf", "  Petal.Width: -Inf, 0.8, 1.75, Inf",
+                "", "FsDiscretizeTransformer allows to discretize data using",
+                "discretize_transform(disc, newData) function.")
+  expect_equal(desc, expected)
 })
 
 test_that("Test drop columns", {
